@@ -207,7 +207,7 @@ def code_check_description(
             details = f"{Verb} {long_desc} in at most {limits[1]} places."
     elif limits[0] == 1:
         if limits[1] is None:
-            details = f"{Verb} {long_desc} in at least once place."
+            details = f"{Verb} {long_desc} in at least one place."
         elif limits[1] == 1:
             details = f"{Verb} {long_desc} in exactly one place."
         else:
