@@ -33,12 +33,6 @@ import ast
 
 import turtle
 
-try:
-    import optimism
-    OPTIMISTIC = True
-except Exception:
-    OPTIMISTIC = False
-
 from . import load
 from . import mast
 from . import context_utils
@@ -163,12 +157,6 @@ def create_module_import_payload(
             sandbox=None
         )
 
-        # Attempt to release any input capturing set up by optimism calls
-        # in the file we just ran:
-        if OPTIMISTIC:
-            optimism.restoreOutput()
-            optimism.restoreInput()
-
         result = {
             "original_source": original_source,
             "source": fixed,
@@ -226,7 +214,7 @@ def create_run_function_payload(
     fname,
     posargs=None,
     kwargs=None,
-    copy_args=False
+    copy_args=True
 ):
     """
     Creates a payload function which retrieves a function from the
@@ -237,16 +225,17 @@ def create_run_function_payload(
     later checks, and the function name is placed into a "function"
     context slot.
 
-    If `copy_args` is set to True, deep copies of argument values will be
-    made before they are passed to the target function (note that keyword
-    argument keys are not copied, although they should be strings in any
-    case). The "args" and "kwargs" slots will also get copies of the
-    arguments, not the original values, and these will be separate copies
-    from those given to the function, so they'll retain the values used
-    as input even after the function is finished. However, "used_args"
-    and "used_kwargs" slots will be added if `copy_args` is set to true
-    that hold the actual arguments sent to the function so that any
-    changes made by the function can be measured if necessary.
+    If `copy_args` is set to True (the default), deep copies of argument
+    values will be made before they are passed to the target function
+    (note that keyword argument keys are not copied, although they should
+    be strings in any case). The "args" and "kwargs" slots will also get
+    copies of the arguments, not the original values, and these will be
+    separate copies from those given to the function, so they'll retain
+    the values used as input even after the function is finished.
+    However, "used_args" and "used_kwargs" slots will be added if
+    `copy_args` is set to true that hold the actual arguments sent to the
+    function so that any changes made by the function can be measured if
+    necessary.
 
     If the function name or any of the argument values (or keyword
     argument keys) are `potluck.context_utils.ContextualValue` instances,
@@ -456,6 +445,18 @@ def create_run_harness_payload(
     return payload
 
 
+def make_module(statements):
+    """
+    Creates an ast.Module object from a list of statements. Sets empty
+    type_ignores if we're in a version that requires them.
+    """
+    vi = sys.version_info
+    if vi[0] > 3 or vi[0] == 3 and vi[1] >= 8:
+        return ast.Module(statements, [])
+    else:
+        return ast.Module(statements)
+
+
 def create_execute_code_block_payload(block_name, src, nodes=None):
     """
     Creates a payload function which executes a series of statements
@@ -506,7 +507,7 @@ def create_execute_code_block_payload(block_name, src, nodes=None):
         env.update(module.__dict__)
 
         if len(start) > 0:
-            code = compile(ast.Module(start), block_name, 'exec')
+            code = compile(make_module(start), block_name, 'exec')
             exec(code, env)
 
         if isinstance(last, ast.Expr):
@@ -520,7 +521,7 @@ def create_execute_code_block_payload(block_name, src, nodes=None):
         else:
             # Guess it wasn't an expression; just execute it
             last_code = compile(
-                ast.Module([last]),
+                make_module([last]),
                 block_name + "(final)",
                 'exec'
             )
@@ -544,7 +545,8 @@ def create_execute_code_block_payload(block_name, src, nodes=None):
 def run_for_base_and_ref_values(
     payload,
     used_by_both=None,
-    cache_ref=True
+    cache_ref=True,
+    ref_only=False
 ):
     """
     Accepts a payload function and returns a modified payload function
@@ -565,6 +567,10 @@ def run_for_base_and_ref_values(
     incorrect, you should set `cache_ref` to False to actually run the
     reference payload every time.
 
+    If you only care about the reference results (e.g., when compiling a
+    snippet) you can set ref_only to true, and the initial run will be
+    skipped.
+
     TODO: Shelf doesn't support multiple-concurrent access!!!
     TODO: THIS
     """
@@ -581,7 +587,10 @@ def run_for_base_and_ref_values(
         time.
         """
         # Get initial results
-        full_result = payload(context)
+        if ref_only:
+            full_result = {}
+        else:
+            full_result = payload(context)
 
         # Figure out our cache key
         taskid = context["task_info"]["id"]
@@ -870,29 +879,8 @@ def with_fake_input(payload, inputs, extra_policy="error"):
         reset_input()
         builtins.input = mock_input
 
-        # If we're dealing with optimism, it's mechanism for providing
-        # input (replacing stdin) won't work with our mock_input
-        # function! So we need to patch that up, and let
-        # optimism-specified input override mock input until
-        # restoreInput is called.
-        if OPTIMISTIC:
-            original_provideInput = optimism.provideInput
-
-            def provideInputNoMock(*args, **kwargs):
-                """
-                Disables mock input and calls original provideInput.
-                """
-                builtins.input = original_input
-                original_provideInput(*args, **kwargs)
-
-            original_restoreInput = optimism.restoreInput
-
-            def restoreInputToMock(*args, **kwargs):
-                builtins.input = mock_input
-                original_restoreInput(*args, **kwargs)
-
-            optimism.provideInput = provideInputNoMock
-            optimism.restoreInput = restoreInputToMock
+        # TODO: Is this compatible with optimism's input-manipulation?
+        # TODO: Make this work with optimism's stdin-replacement
 
         # Run the payload
         try:
@@ -903,11 +891,6 @@ def with_fake_input(payload, inputs, extra_policy="error"):
             reset_input()
             reset_input()
 
-            # Reset optimism input mechanisms
-            if OPTIMISTIC:
-                optimism.provideInput = original_provideInput
-                optimism.restoreInput = original_restoreInput
-
         # Add "inputs" and "input_policy" context slots to the result
         result["inputs"] = inputs
         result["input_policy"] = extra_policy
