@@ -78,7 +78,6 @@ the code is run.
 import textwrap
 import re
 import os
-import sys
 
 import pygments
 
@@ -297,22 +296,23 @@ def wrapped_with_prefix(obj, prefix, indentation_level=0):
 
 def extract(context, key):
     """
-    Gets value from a context but shows the context's error log if it
-    can't.
+    Gets value from a context but raises a ValueError showing the
+    context's error log if it can't.
     """
     if key in context:
         return context[key]
     else:
+        # Note: we use a ValueError here instead of a KeyError because
+        # KeyError uses repr on its message...
         if "ref_error_log" in context:
-            print(
+            raise ValueError(
                 (
                     "Error: context is missing the '{}' key. Error log"
                     " is:\n{}"
                 ).format(key, context["ref_error_log"]),
-                file=sys.stderr
             )
         else:
-            print(
+            raise ValueError(
                 "Error: context is missing the '{}' key. No error log"
                 " available."
             )
@@ -909,10 +909,10 @@ class FunctionCalls(Snippet):
               + "\nFull log is:\n"
               + context.get("ref_error_log", '<missing>')
             )
-        fname = context["ref_function"]
-        value = context["ref_value"]
-        args = context["ref_args"]
-        kwargs = context["ref_kwargs"]
+        fname = extract(context, "ref_function")
+        value = extract(context, "ref_value")
+        args = extract(context, "ref_args")
+        kwargs = extract(context, "ref_kwargs")
         captured = context.get("ref_output", '')
         captured_errs = context.get("ref_error_log", '')
 
