@@ -29,11 +29,8 @@ def whatever(a, b):
 
 import optimism as opt
 
-opt.testCase(whatever(True, True))
-opt.expectResult(1)
-opt.testCase(whatever(True, False))
-opt.expectResult(2)
-opt.testCase(whatever(False, True))
-opt.expectResult(2)
-opt.testCase(whatever(False, False))
-opt.expectResult(3)
+m = opt.testFunction(whatever)
+m.case(True, True).checkResult(1)
+m.case(True, False).checkResult(2)
+m.case(False, True).checkResult(2)
+m.case(False, False).checkResult(3)
