@@ -6,9 +6,9 @@ Peter Mawhorter 2021-6-28
 
 from potluck import specifications as spec
 
-# Require 'from turtleBeads import *' (since this will also pull in
+# Require some kind of turtleBeads import (since this will also pull in
 # turtle stuff, we don't require a separate turtle import.
-spec.Import("turtleBeads", '*')
+spec.Import("turtleBeads", 'any')
 
 for fcn in [
     ["forward", "fd", "backward", "bk", "back"],
@@ -36,9 +36,11 @@ rubric = spec.rubric()
 # Specifications tests using the meta module:
 from potluck import meta # noqa E402
 
+meta.example("perfect")
+
 meta.example("imperfect")
 
-meta.expect("failed", "procedure", "core", "import everything")
+meta.expect("failed", "procedure", "core", "import the turtleBeads module")
 meta.expect("failed", "procedure", "core", "call left")
 meta.expect("failed", "procedure", "extra", "call drawCircle")
 meta.expect("failed", "procedure", "extra", "call begin_fill")
