@@ -90,6 +90,18 @@ REPORT_EXPECTS = {
     }
 }
 
+# Expectations about validation reports
+VALIDATION_EXPECTS = {
+    "functionsTest": {
+        "perfect": { "evaluation": "excellent" },
+        "imperfect": { "evaluation": "partially complete" },
+    },
+    "synthTest": {
+        "perfect": { "evaluation": "excellent" },
+        "imperfect": { "evaluation": "partially complete" },
+    }
+}
+
 # TODO: Expectations for instructions and for snippets!
 
 
@@ -142,7 +154,10 @@ def logfile():
     """
     result = pathlib.Path("logs", "pytest.log")
     yield result
-    result.unlink()
+    try:
+        result.unlink()
+    except Exception:
+        pass
 
 
 @pytest.fixture
@@ -153,7 +168,10 @@ def rubricfile(taskid):
     """
     result = pathlib.Path("rubrics", f"rubric-{taskid}.html")
     yield result
-    result.unlink()
+    try:
+        result.unlink()
+    except Exception:
+        pass
 
 
 @pytest.fixture
@@ -166,8 +184,37 @@ def reportfiles(taskid, username):
     r_json = pathlib.Path("reports", f"pytest-{username}-{taskid}.json")
     r_html = r_json.with_suffix(".html")
     yield (r_json, r_html)
-    r_json.unlink()
-    r_html.unlink()
+    try:
+        r_json.unlink()
+    except Exception:
+        pass
+    try:
+        r_html.unlink()
+    except Exception:
+        pass
+
+
+@pytest.fixture
+def validationreportfiles(taskid, username):
+    """
+    A fixture that yields a pair of validation report JSON and HTML
+    filenames and removes those files after the test is complete. The
+    test must create the file.
+    """
+    r_json = pathlib.Path(
+        "reports",
+        f"pytest-{username}-{taskid}-validation.json"
+    )
+    r_html = r_json.with_suffix(".html")
+    yield (r_json, r_html)
+    try:
+        r_json.unlink()
+    except Exception:
+        pass
+    try:
+        r_html.unlink()
+    except Exception:
+        pass
 
 
 def check_log_is_clean(logfile):
@@ -272,3 +319,50 @@ def test_specifications_checks(in_evaldir, taskid, logfile):
 
     assert "All examples met expectations." in log
     assert "Check of solution code passed." in log
+
+
+def test_validation(
+    in_evaldir,
+    taskid,
+    username,
+    validationreportfiles,
+    logfile
+):
+    """
+    Tests the potluck_eval script validation mode for a certain
+    task/user example.
+    """
+    # Skip this test if there aren't any expectations for it: not all
+    # tasks can be validated (they may not define any validation goals).
+    if taskid not in VALIDATION_EXPECTS:
+        return
+    assert not logfile.exists()
+    r_json, r_html = validationreportfiles
+    assert not r_json.exists()
+    assert not r_html.exists()
+    result = subprocess.run(
+        [
+            "potluck_eval",
+            "--validate",
+            "--import-from", IMPORT_FROM,
+            "-t", taskid,
+            "-u", username,
+            "--log", str(logfile),
+            "--outfile", str(r_json)
+        ]
+    )
+    assert result.returncode == 0
+    check_log_is_clean(logfile)
+
+    assert r_json.is_file()
+    assert r_html.is_file()
+
+    with r_json.open() as fin:
+        report = json.load(fin)
+
+    if taskid in VALIDATION_EXPECTS:
+        if username in VALIDATION_EXPECTS[taskid]:
+            expectations = VALIDATION_EXPECTS[taskid][username]
+            for key in expectations:
+                assert key in report
+                assert report[key] == expectations[key]
